@@ -10,7 +10,7 @@ from sentry_sdk import init as sentry_init, Hub as SentryHub
 # Package information
 # ===================
 
-__version__ = "0.3.1"
+__version__ = "0.4.1"
 __project__ = "muffin-sentry"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -29,9 +29,9 @@ class Plugin(BasePlugin):
     }
     current_scope = ContextVar('sentry_scope', default=None)
 
-    def init(self, app, **options):
+    def setup(self, app, **options):
         """Initialize Sentry Client."""
-        super().init(app, **options)
+        super().setup(app, **options)
 
         if not self.cfg.dsn:
             return
